<?php

/*
 * @package RS-SITE
 * @copyright (c) 2013 Alexey Glumov aka Rio-Shaman (support@rio-shaman.ru)
 * @license GNU General Public License version 2; see LICENSE.txt
 *
 */
 

if(!defined('RS-SITE')) die();

class workDB
{
    var $fields;
    var $table_suffix;
    
    function workDB()
    {
        $this->trigger = new workTrigger();
    }
    
    /* СОЗДАНИЕ/УДАЛЕНИЕ/РЕДАКТИРОВАНИЕ ТАБЛИЦ */
    
    /*создание таблиц*/
    
    function clear()
    {
        $this->fields       = array();
        $this->table_suffix = '';
    }
    
    function set_suffix_table($suffix)
    {
        $this->table_suffix = $suffix;
    }
    
    function set_type_field($name, $default, $type, $length_array = array())
    {
        $length = '';
        
        switch ($type)
        {
            case 'int':
                $length = (!isset($length_array['int']))     ? '10'   : $length_array['int'];
                break;
            case 'float':
                $length = (!isset($length_array['float']))   ? '15,2' : $length_array['float'];
                break;
            case 'decimal':
                $length = (!isset($length_array['decimal'])) ? '15,2' : $length_array['decimal'];
                break;
            case 'varchar':
                $length = (!isset($length_array['varchar'])) ? '255'  : $length_array['varchar'];
                break;
        }
        
        $this->fields[] = array(
            'name'    => $name,
            'type'    => $type,
            'default' => ($default !== FALSE) ? $default : 'AUTO_INCREMENT',
            'length'  => $length
        );
    }
    
    /* создание таблицы */
    function accept_create_table($name)
    {
        $sql = "CREATE TABLE IF NOT EXISTS `rs_".$name."_".$this->table_suffix."` (";
        
        $fields_array = array();
        
        foreach ($this->fields as $field)
        {
            if ($field['default'] == 'AUTO_INCREMENT')
                $primary = $field['name'];
            
            $str  = "`".$field['name']."` ".$field['type'];
            $str .= ($field['length'] != '') ? "(".$field['length'].")" : '' ;
            $str .= " NOT NULL";
            $str .= ($field['default'] == 'AUTO_INCREMENT') ? ' '.$field['default'] : ( (empty($field['default'])) ? '' : " DEFAULT '".$field['default']."'" );
            
            $fields_array[] = $str;
        }
        $sql .= implode(',', $fields_array).", PRIMARY KEY (`".$primary."`)) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;";
        
        mysqli_query($GLOBALS['rssite']['cfg']['mysqlRS'], $sql);
    }

    /* удаление таблицы */

    function accept_delete_table($name)
    {
        $sql = "DROP TABLE `rs_".$name."_".$this->table_suffix."`;";
                
        mysqli_query($GLOBALS['rssite']['cfg']['mysqlRS'], $sql);
    }    
    
    /* добавление нового поля */
    function accept_add_field($name)
    {
        $field = $this->fields[0];
        
        $sql  = "ALTER TABLE `rs_".$name."_".$this->table_suffix."` ADD `".$field['name']."` ".$field['type'];
        $sql .= ($field['length'] != '') ? "( ".$field['length']." )" : '';
        $sql .= " NOT NULL";
        $sql .= ($field['default'] == '') ? '' : " DEFAULT '".$field['default']."'";
        
        mysqli_query($GLOBALS['rssite']['cfg']['mysqlRS'], $sql);
    }
    
    /* редактирование поля */

    function accept_edit_field($name, $old_field_name)
    {
        $field = $this->fields[0];
        
        $sql  = "ALTER TABLE `rs_".$name."_".$this->table_suffix."` CHANGE `".$old_field_name."` `".$field['name']."` ".$field['type'];
        $sql .= ($field['length'] != '') ? "( ".$field['length']." )" : '';
        $sql .= " NOT NULL";
        $sql .= ($field['default'] == '') ? '' : " DEFAULT '".$field['default']."'";
        
        mysqli_query($GLOBALS['rssite']['cfg']['mysqlRS'], $sql);
    }

    /* удаление поля */

    function accept_delete_field($name)
    {
        $field = $this->fields[0];
        
        $sql  = "ALTER TABLE `rs_".$name."_".$this->table_suffix."` DROP `".$field['name']."`;";
        
        mysqli_query($GLOBALS['rssite']['cfg']['mysqlRS'], $sql);
    }
    
    /*селект запрос с функцией COUNT в базу данных*/
    
    function accept_count_select($sql)
    {   
        $GLOBALS['rssite']['sys']['maxsql']['select']++;
        
        if (!$result = mysqli_query($GLOBALS['rssite']['cfg']['mysqlRS'], $sql))
            return 0;
        
        $myrow = mysqli_fetch_row($result);
        
        return $myrow[0];
    }

    /*селект запрос в базу данных*/
    
    function accept_select($sql)
    {
        $GLOBALS['rssite']['sys']['maxsql']['select']++;

        $myrow = FALSE;
        
        // запускаем триггер (если он существует), для селекта с событием ДО
        if ($this->trigger->getTrigger())
            $this->trigger->runTrigger('to', 'select');

        if ($result = mysqli_query($GLOBALS['rssite']['cfg']['mysqlRS'], $sql))
            $myrow = mysqli_fetch_assoc($result);
        
        if ($myrow != FALSE)
        {   
            $i=0;
            do
            {
                foreach($myrow as $key => $value) $massiv[$i][$key] = $value;
                $i++;
            }
            while ($myrow = mysqli_fetch_assoc($result));

            // запускаем триггер (если он существует), для селекта с событием ПОСЛЕ
            if ($this->trigger->getTrigger())
                $this->trigger->runTrigger('after', 'select');
            
            return $massiv;
        }
        else {
            $error = mysqli_error($GLOBALS['rssite']['cfg']['mysqlRS']);
            
            if (!empty($error)) {
                echo $error;
                die();
            }
            
            return FALSE;
        }
    }
    
    /*апдейт запрос в базу данных*/ 
    
    function accept_update($what, $table, $where)
    {
    //$table - таблица (строка)
    //$what - новые значение полей (массив)
    //$where - условие (строка)
        $GLOBALS['rssite']['sys']['maxsql']['update']++;
        
        // запускаем триггер (если он существует), для апдейта с событием ДО
        if ($this->trigger->getTrigger())
            $this->trigger->runTrigger('to', 'update');
        
        foreach($what as $key => $value)
            $sql[] = $key."='".$value."'";
        
        $sql = "UPDATE ".$table." SET ".implode (", ", $sql)." WHERE ".$where;
        
        if(!mysqli_query ($GLOBALS['rssite']['cfg']['mysqlRS'], $sql))
            return FALSE;
            
        // запускаем триггер (если он существует), для селекта с событием ПОСЛЕ
        if ($this->trigger->getTrigger())
            $this->trigger->runTrigger('after', 'update');
        
        return TRUE;
    }
    
    /*инсерт запрос в базу данных*/
    
    function accept_insert($what, $table, $return = FALSE)
    {
    //$what - значения полей (массив)
    //$table - таблица (cтрока)
        $GLOBALS['rssite']['sys']['maxsql']['insert']++;
        
        // запускаем триггер (если он существует), для инсерта с событием ДО
        if ($this->trigger->getTrigger())
            $this->trigger->runTrigger('to', 'insert');
        
        foreach($what as $key => $value)
        {
            $sql_input[] = $key;
            $sql_value[] = "'".$value."'";
        }
        
        $sql = "INSERT INTO ".$table." (".implode(", ", $sql_input).") VALUES (".implode(", ", $sql_value).")";
        
        if(!mysqli_query($GLOBALS['rssite']['cfg']['mysqlRS'], $sql))
            return FALSE;
        
        if ($return != FALSE)
            return mysqli_insert_id($GLOBALS['rssite']['cfg']['mysqlRS']);
            
        // запускаем триггер (если он существует), для инсерта с событием ПОСЛЕ
        if ($this->trigger->getTrigger())
            $this->trigger->runTrigger('after', 'insert');

        return TRUE;
    }
    
    /*делет запрос в базу данных*/
    
    function accept_delete($sql)
    {
        /* "DELETE FROM table WHERE id='1'" */
        
        $GLOBALS['rssite']['sys']['maxsql']['delete']++;
        
        // запускаем триггер (если он существует), для делет с событием ДО
        if ($this->trigger->getTrigger())
            $this->trigger->runTrigger('to', 'delete');
        
        if(!mysqli_query($GLOBALS['rssite']['cfg']['mysqlRS'], $sql))
            return FALSE;
            
        // запускаем триггер (если он существует), для делет с событием ПОСЛЕ
        if ($this->trigger->getTrigger())
            $this->trigger->runTrigger('after', 'delete');
        
        return TRUE;
    }
}
?>